# audioviz-colab ##

* An user-friendly music information retrieval visualization API interfacing with Google Colab
* Coordinated by Prof. [Li Su](https://homepage.iis.sinica.edu.tw/pages/lisu/index_en.html), Prof. [Yu-Fen Huang](https://yfhuang.info/) from the [Music and Culture Technology Lab](https://sites.google.com/view/mctl/), Academia Sinica, Taipei, Taiwan
* A collaration project with graduate students from National Tsing Hua University, Hsinchu, Taiwan

## Introduction to this packages ##

* Custom visualization wrappers for open source module [librosa](https://librosa.org/doc/latest/index.html)
* Using open source graphing library [Plotly](https://plotly.com/python/) to enhance visualization capabilities
* Direcctly integrated with Google Colab functions to provide platform-free user experience
* Please refer to [official page](https://grace1287986s-organization.gitbook.io/musicai-ui-space-v2/) for more details

## Installation and Dependency ##

### Installation ###

* PyPi installation

  ```bash
  pip install audioviz
  ```

* setup.py

## Developer Demo ##
![alt text](panel.png "Title")

## Future Works ##

* Colab upload solution
  * Direct instruction
* Programming Copilot
